<?php
/**
 * Customizer Option - Counter
 *
 * @package One_Hive
 */

$defaults = one_hive_get_default_theme_options();

$background_choices = one_hive_get_background_choices();

// Section - Feature
$wp_customize->add_section( 'one_hive_counter_section', array(
	'priority'		=> 20,
	'title'			=> esc_html__( 'Counter Section', 'one-hive' ),
	'panel'			=> 'one_hive_home_page_options'	
) );

// Enable Feature
$wp_customize->add_setting( 'one_hive_enable_counter_section', array(
	'sanitize_callback'	=> 'one_hive_sanitize_checkbox',
	'default'			=> $defaults['one_hive_enable_counter_section'],
) );

$wp_customize->add_control( 'one_hive_enable_counter_section', array(
	'label'				=> esc_html__( 'Enable Counter Section', 'one-hive' ),
	'section'			=> 'one_hive_counter_section',
	'type'				=> 'checkbox',
) );

// Counter Section ID
$wp_customize->add_setting( 'one_hive_counter_section_id', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_counter_section_id'],
) );

$wp_customize->add_control( 'one_hive_counter_section_id', array(
	'label'				=> esc_html__( 'Counter Section ID', 'one-hive' ),
	'description'		=> esc_html__( 'Counter Section ID is used to navigate to counter section from Menu Item. It will be active when your site is one page site.', 'one-hive' ),
	'section'			=> 'one_hive_counter_section',
	'type'				=> 'text',
	'active_callback'	=> 'one_hive_enable_counter_section_id'
) );

// Counter Background
$wp_customize->add_setting( 'one_hive_counter_background', array(
	'sanitize_callback'	=> 'one_hive_sanitize_select',
	'default'			=> $defaults['one_hive_counter_background'],
) );

$wp_customize->add_control( 'one_hive_counter_background', array(
	'label'				=> esc_html__( 'Counter Background', 'one-hive' ),
	'section'			=> 'one_hive_counter_section',
	'type'				=> 'select',
	'choices' 			=> $background_choices,
	'active_callback'	=> 'one_hive_is_active_counter_section'
) );

// Counter Background Image
$wp_customize->add_setting( 'one_hive_counter_image_background', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_counter_image_background'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'one_hive_counter_image_background', array(
	'label'				=> esc_html__( 'Counter Background Image', 'one-hive' ),
	'section'			=> 'one_hive_counter_section',
	'active_callback'	=> 'one_hive_is_image_counter_section_background'
) ) );

// Counter Background Color
$wp_customize->add_setting( 'one_hive_counter_color_background', array(
	'sanitize_callback'	=> 'sanitize_hex_color',
	'default'			=> $defaults['one_hive_counter_color_background'],
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'one_hive_counter_color_background', array(
	'label'				=> esc_html__( 'Counter Background Color', 'one-hive' ),
	'section'			=> 'one_hive_counter_section',
	'active_callback'	=> 'one_hive_is_color_counter_section_background'
) ) );

// Counters
$wp_customize->add_setting( 'one_hive_counter_contents', array(
	'sanitize_callback' => 'one_hive_repeater_data_field',
	'transport' => 'refresh',
) );

$wp_customize->add_control( new One_Hive_Repeater_Control( $wp_customize, 'one_hive_counter_contents', array(
    'label' 		=> esc_html__('Counters', 'one-hive'),
    'description'   => '',
    'section'       => 'one_hive_counter_section',
    'live_title_id' => '', // apply for unput text and textarea only
    'title_format'  => '', // [live_title]
    'max_item'      => 4, // Maximum item can add
    'limited_msg' 	=> '',
    'fields'    => array(
    	'one_hive_counter_title'  => array(
        	'title' => esc_html__('Counter Title', 'one-hive'),
        	'type'  => 'text',
        ),
        'one_hive_counter_icon'  => array(
        	'title' => esc_html__('Counter Icon', 'one-hive'),
        	'type'  => 'icon',
        ),
        'one_hive_counter_no'  => array(
        	'title' => esc_html__('Counter Number', 'one-hive'),
        	'type'  => 'number',
        ),
    ),
    'active_callback'	=> 'one_hive_is_active_counter_section'
) ) );
