<?php
/**
 * Customizer Option - CTA
 *
 * @package One_Hive
 */

$defaults = one_hive_get_default_theme_options();

$pages = one_hive_get_pages();

$background_choices = one_hive_get_cta_background_choices();

// Section - CTA
$wp_customize->add_section( 'one_hive_cta_section', array(
	'priority'		=> 20,
	'title'			=> esc_html__( 'CTA Section', 'one-hive' ),
	'panel'			=> 'one_hive_home_page_options'	
) );

// Enable CTA
$wp_customize->add_setting( 'one_hive_enable_cta_section', array(
	'sanitize_callback'	=> 'one_hive_sanitize_checkbox',
	'default'			=> $defaults['one_hive_enable_cta_section'],
) );

$wp_customize->add_control( 'one_hive_enable_cta_section', array(
	'label'				=> esc_html__( 'Enable CTA Section', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'type'				=> 'checkbox',
) );

// CTA Section ID
$wp_customize->add_setting( 'one_hive_cta_section_id', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_cta_section_id'],
) );

$wp_customize->add_control( 'one_hive_cta_section_id', array(
	'label'				=> esc_html__( 'CTA Section ID', 'one-hive' ),
	'description'		=> esc_html__( 'CTA Section ID is used to navigate to CTA section from Menu Item. It will be active when your site is one page site.', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'type'				=> 'text',
	'active_callback'	=> 'one_hive_enable_cta_section_id'
) );

// CTA Page
$wp_customize->add_setting( 'one_hive_cta_page', array(
	'sanitize_callback'	=> 'one_hive_sanitize_dropdown_pages',
	'default'			=> $defaults['one_hive_cta_page'],
) );

$wp_customize->add_control( 'one_hive_cta_page', array(
	'label'				=> esc_html__( 'CTA Page', 'one-hive' ),
	'description'		=> esc_html__( 'Page Contents are used for the image and CTA content', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'type'				=> 'select',
	'choices'			=> $pages,
	'active_callback'	=> 'one_hive_is_active_cta_section'
) );

// CTA Background
$wp_customize->add_setting( 'one_hive_cta_background', array(
	'sanitize_callback'	=> 'one_hive_sanitize_select',
	'default'			=> $defaults['one_hive_cta_background'],
) );

$wp_customize->add_control( 'one_hive_cta_background', array(
	'label'				=> esc_html__( 'CTA Background', 'one-hive' ),
	'description'		=> esc_html__( 'If featured image of the page selected is set, then background of CTA section will be that featured image. So to set color or image as background featured image should be removed.', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'type'				=> 'select',
	'choices' 			=> $background_choices,
	'active_callback'	=> 'one_hive_is_active_cta_section'
) );

// CTA Background Image
$wp_customize->add_setting( 'one_hive_cta_image_background', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_cta_image_background'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'one_hive_cta_image_background', array(
	'label'				=> esc_html__( 'CTA Background Image', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'active_callback'	=> 'one_hive_is_image_cta_section_background'
) ) );

// CTA Background Color
$wp_customize->add_setting( 'one_hive_cta_color_background', array(
	'sanitize_callback'	=> 'sanitize_hex_color',
	'default'			=> $defaults['one_hive_cta_color_background'],
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'one_hive_cta_color_background', array(
	'label'				=> esc_html__( 'CTA Background Color', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'active_callback'	=> 'one_hive_is_color_cta_section_background'
) ) );

// CTA Button Title
$wp_customize->add_setting( 'one_hive_cta_button_title', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_cta_button_title'],
) );

$wp_customize->add_control( 'one_hive_cta_button_title', array(
	'label'				=> esc_html__( 'CTA Button Title', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'active_callback'	=> 'one_hive_is_active_cta_section'
) );

// CTA Button Link
$wp_customize->add_setting( 'one_hive_cta_button_link', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_cta_button_link'],
) );

$wp_customize->add_control( 'one_hive_cta_button_link', array(
	'label'				=> esc_html__( 'CTA Button Link', 'one-hive' ),
	'section'			=> 'one_hive_cta_section',
	'active_callback'	=> 'one_hive_is_active_cta_section'
) );