<?php
/**
 * Customizer Option - News
 *
 * @package One_Hive
 */

$defaults = one_hive_get_default_theme_options();

$background_choices = one_hive_get_background_choices();

// Section - News
$wp_customize->add_section( 'one_hive_news_section', array(
	'priority'		=> 20,
	'title'			=> esc_html__( 'News Section', 'one-hive' ),
	'panel'			=> 'one_hive_home_page_options'	
) );

// Enable News
$wp_customize->add_setting( 'one_hive_enable_news_section', array(
	'sanitize_callback'	=> 'one_hive_sanitize_checkbox',
	'default'			=> $defaults['one_hive_enable_news_section'],
) );

$wp_customize->add_control( 'one_hive_enable_news_section', array(
	'label'				=> esc_html__( 'Enable News Section', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'type'				=> 'checkbox',
) );

// News Section ID
$wp_customize->add_setting( 'one_hive_news_section_id', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_news_section_id'],
) );

$wp_customize->add_control( 'one_hive_news_section_id', array(
	'label'				=> esc_html__( 'News Section ID', 'one-hive' ),
	'description'		=> esc_html__( 'News Section ID is used to navigate to news section from Menu Item. It will be active when your site is one page site.', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'type'				=> 'text',
	'active_callback'		=> 'one_hive_enable_news_section_id'
) );

// News Background
$wp_customize->add_setting( 'one_hive_news_background', array(
	'sanitize_callback'	=> 'one_hive_sanitize_select',
	'default'			=> $defaults['one_hive_news_background'],
) );

$wp_customize->add_control( 'one_hive_news_background', array(
	'label'				=> esc_html__( 'News Background', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'type'				=> 'select',
	'choices' 			=> $background_choices,
	'active_callback'		=> 'one_hive_is_active_news_section'
) );

// News Background Image
$wp_customize->add_setting( 'one_hive_news_image_background', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'			=> $defaults['one_hive_news_image_background'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'one_hive_news_image_background', array(
	'label'				=> esc_html__( 'News Background Image', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'active_callback'	=> 'one_hive_is_image_news_section_background'
) ) );

// News Background Color
$wp_customize->add_setting( 'one_hive_news_color_background', array(
	'sanitize_callback'	=> 'sanitize_hex_color',
	'default'			=> $defaults['one_hive_news_color_background'],
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'one_hive_news_color_background', array(
	'label'				=> esc_html__( 'News Background Color', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'active_callback'	=> 'one_hive_is_color_news_section_background'
) ) );

// News Section Title
$wp_customize->add_setting( 'one_hive_news_section_title', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_news_section_title'],
) );

$wp_customize->add_control( 'one_hive_news_section_title', array(
	'label'				=> esc_html__( 'News Section Title', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'active_callback'		=> 'one_hive_is_active_news_section'
) );

// News Section Description
$wp_customize->add_setting( 'one_hive_news_section_description', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'			=> $defaults['one_hive_news_section_description'],
) );

$wp_customize->add_control( 'one_hive_news_section_description', array(
	'label'				=> esc_html__( 'News Section Description', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'active_callback'		=> 'one_hive_is_active_news_section'
) );

// News Post Category
$wp_customize->add_setting( 'one_hive_news_post_category', array(
	'sanitize_callback'	=> 'one_hive_sanitize_choices',
) );

$wp_customize->add_control( new One_Hive_Dropdown_Multiple_Chooser( $wp_customize, 'one_hive_news_post_category', array(
	'label'				=> esc_html__( 'News Post Category', 'one-hive' ),
	'description'		=> esc_html__( 'Select one or more than one categories', 'one-hive' ),
	'section'			=> 'one_hive_news_section',
	'type'				=> 'select',
	'choices'			=> one_hive_get_blog_cat(),
	'active_callback'		=> 'one_hive_is_active_news_section'
) ) );

// News Posts Number
$wp_customize->add_setting( 'one_hive_news_posts_number', array(
	'sanitize_callback'		=> 'one_hive_sanitize_number',
	'default'				=> $defaults['one_hive_news_posts_number'] 
) ); 

$wp_customize->add_control( 'one_hive_news_posts_number', array(
	'label'					=> esc_html__( 'Numbers of News Posts', 'one-hive' ),
	'section'				=> 'one_hive_news_section',
	'type'					=> 'number',
	'active_callback'		=> 'one_hive_is_active_news_section'
) );